/*----------------------------------------------------------------------------*/
/*                                                                            */
/* Copyright (c) 1995, 2004 IBM Corporation. All rights reserved.             */
/* Copyright (c) 2005 Rexx Language Association. All rights reserved.         */
/*                                                                            */
/* This program and the accompanying materials are made available under       */
/* the terms of the Common Public License v1.0 which accompanies this         */
/* distribution. A copy is also available at the following address:           */
/* http://www.ibm.com/developerworks/oss/CPLv1.0.htm                          */
/*                                                                            */
/* Redistribution and use in source and binary forms, with or                 */
/* without modification, are permitted provided that the following            */
/* conditions are met:                                                        */
/*                                                                            */
/* Redistributions of source code must retain the above copyright             */
/* notice, this list of conditions and the following disclaimer.              */
/* Redistributions in binary form must reproduce the above copyright          */
/* notice, this list of conditions and the following disclaimer in            */
/* the documentation and/or other materials provided with the distribution.   */
/*                                                                            */
/* Neither the name of Rexx Language Association nor the names                */
/* of its contributors may be used to endorse or promote products             */
/* derived from this software without specific prior written permission.      */
/*                                                                            */
/* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        */
/* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT          */
/* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS          */
/* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT   */
/* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,      */
/* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED   */
/* TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,        */
/* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY     */
/* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING    */
/* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         */
/* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               */
/*                                                                            */
/*----------------------------------------------------------------------------*/


#ifndef REXXCTYPE_H_INCLUDED
#define REXXCTYPE_H_INCLUDED

/*********************************************************************/
/*                                                                   */
/*   The following mask values and macro definitions are used by     */
/*      TOKENIZE.C and TOKENS.C to determine attributes of characters*/
/*      during the tokenization of REXX programs, with regards to    */
/*      their positional chatacteristics in symbols and numbers, as  */
/*      well as the invocation of functions based on those           */
/*      characteristics.                                             */
/*                                                                   */
/*********************************************************************/

#define STARTSYM 0x80                  /* character can start symbol */
#define INSYM 0x40                     /* character can be in symbol */
#define INNUM 0x20                     /* character can be in number */
#define INALPHA 0x10                   /* character is alphabetic    */
#define LOMASK 0x0f                    /* mask out hi-order bits     */
#define InSym(c) (first_char[c] & INSYM)
#define StartSym(c) (first_char[c] & STARTSYM)
#define InNum(c) (first_char[c] & INNUM)
#define FunctionNo(c) (first_char[c] & LOMASK)

/*********************************************************************/
/*                                                                   */
/* Definitions of character functions                                */
/*                                                                   */
/*********************************************************************/
#undef islower
#undef isupper
#undef isdigit
#undef isspace
#undef isxdigit
#undef tolower
#undef toupper

#define toupper(c)    ( upper_case_table[(UCHAR)(c)] )
#define tolower(c)    ( lower_case_table[(UCHAR)(c)] )
#define islower(c)    ( upper_case_table[(UCHAR)(c)] != (UCHAR)(c) )
#define isupper(c)    ( lower_case_table[(UCHAR)(c)] != (UCHAR)(c) )
#define isdigit(c)    ( (c) >= '0' && (c) <= '9' )
#define isspace(c)    ( (c) == ' ' )
#define isxdigit(c)   ( isdigit(c) || ((c) >= 'a' && (c) <= 'f') || ((c) >= 'A' && (c) <= 'F') )

#endif
